@@ -15,8 +15,6 @@
 
 """Classes for individual Markov chains."""
 
-from __future__ import absolute_import
-
 import numpy
 
 from epsie.proposals import JointProposal
@@ -113,10 +111,9 @@ class Chain(BaseChain):
         self._logl0 = None
         self._blob0 = None
 
-    def _store_proposals(self, *proposals, **kwargs):
+    def _store_proposals(self, *proposals, bit_generator=None):
         """Store either a ``JointProposal`` or the transdimensional proposal
         """
-        bit_generator = kwargs.pop('bit_generator', None)  # Py3XX: delete line
         count = 0
         for prop in proposals:
             try:
@@ -328,9 +325,6 @@ class Chain(BaseChain):
 
     @property
     def acceptance(self):
-        """The history of all of acceptance ratios and accepted booleans,
-        as a structred array.
-        """
         if self.iteration == 0:
             raise ValueError("No acceptance as chain hasn't been stepped "
                              "yet; run step() at least once")
@@ -433,7 +427,6 @@ class Chain(BaseChain):
 
     @property
     def bit_generator(self):
-        """The random bit generator being used."""
         return self.proposal_dist.bit_generator
 
     @property
@@ -510,6 +503,15 @@ class Chain(BaseChain):
             accept = True
         else:
             ar = numpy.exp(logar)
+            if numpy.isnan(ar):
+                raise ValueError('NaN acceptance!'
+                                 '\nchain: {};\nbeta: {};'
+                                 '\ncurrent position: {};'
+                                 '\nproposed position: {};'
+                                 '\nproposal state: {}'
+                                 .format(self.chain_id, self.beta,
+                                         current_pos, proposal,
+                                         self.proposal_dist.state))
             u = self.random_generator.uniform()
             accept = u <= ar
         return accept, ar
