@@ -16,8 +16,6 @@
 
 """Markov chains with parallel tempering."""
 
-from __future__ import absolute_import
-
 import logging
 import numpy
 import copy
@@ -130,7 +128,6 @@ class ParallelTemperedChain(BaseChain):
 
     @property
     def bit_generator(self):
-        """The random bit generator being used."""
         return self._bit_generator
 
     @bit_generator.setter
@@ -581,9 +578,10 @@ class ParallelTemperedChain(BaseChain):
             self.adaptive_annealer(self)
 
 
-class DynamicalAnnealer(object):
-    """
-    Class for dynamical parallel tempering based on algorithm described in [1].
+class DynamicalAnnealer:
+    """Class for dynamical parallel tempering.
+
+    This is based on the algorithm described in [1].
 
     Parameters
     ----------
