@@ -13,17 +13,13 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-from __future__ import absolute_import
-
 import itertools
 
-import numpy
-
 from .base import BaseProposal
 
 
 class JointProposal(BaseProposal):
-    """A collection of jump proposals for multiple parameters.
+    r"""A collection of jump proposals for multiple parameters.
 
     Parameters
     ----------
@@ -41,9 +37,7 @@ class JointProposal(BaseProposal):
     """
     name = 'joint'
 
-    # Py3XX: change kwargs to explicit random_state=None
-    def __init__(self, *proposals, **kwargs):
-        bit_generator = kwargs.pop('bit_generator', None)  # Py3XX: delete line
+    def __init__(self, *proposals, bit_generator=None):
         all_params = list(itertools.chain(*[prop.parameters
                                             for prop in proposals]))
         # check that we don't have multiple proposals for the same parameter
