@@ -13,11 +13,6 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-from __future__ import (absolute_import, division)
-
-from abc import ABCMeta
-from six import add_metaclass
-
 import numpy
 from scipy import stats
 
@@ -201,7 +196,6 @@ class Normal(BaseProposal):
 #
 
 
-@add_metaclass(ABCMeta)
 class AdaptiveSupport(BaseAdaptiveSupport):
     r"""Utility class for adding adaptive variance support to a proposal.
 
@@ -217,8 +211,8 @@ class AdaptiveSupport(BaseAdaptiveSupport):
 
     Notes
     -----
-    For a given parameter, the standard deviation of the :math:`k`th iteration
-    is given by [1]_:
+    For a given parameter, the standard deviation of the :math:`k^{\rm th}`
+    iteration is given by [1]_:
 
     .. math::
 
@@ -379,7 +373,7 @@ class AdaptiveNormal(AdaptiveSupport, Normal):
     def __init__(self, parameters, prior_widths, adaptation_duration,
                  start_step=1, jump_interval=1, **kwargs):
         # set the parameters, initialize the covariance matrix
-        super(AdaptiveNormal, self).__init__(
+        super().__init__(
             parameters, jump_interval=jump_interval,
             jump_interval_duration=adaptation_duration)
         # set up the adaptation parameters
@@ -396,11 +390,10 @@ class AdaptiveNormal(AdaptiveSupport, Normal):
 #
 
 
-@add_metaclass(ABCMeta)
 class SSAdaptiveSupport(BaseAdaptiveSupport):
     r"""Utility class for adding adaptive variance support to a proposal.
 
-    The adaptation algorithm is based on a method in Sivia and Skilling [1]_.
+    The adaptation algorithm is based on a method in Sivia and Skilling [2]_.
 
     Notes
     -----
@@ -428,7 +421,7 @@ class SSAdaptiveSupport(BaseAdaptiveSupport):
 
     References
     ----------
-    .. [1] Sivia D., Skilling J., "Data Analysis: A Bayesian Tutorial,"
+    .. [2] Sivia D., Skilling J., "Data Analysis: A Bayesian Tutorial,"
         Oxford Univ. Press, Oxford (2006)
     """
     n_accepted = None
@@ -533,7 +526,7 @@ class SSAdaptiveNormal(SSAdaptiveSupport, Normal):
     def __init__(self, parameters, cov=None, jump_interval=1,
                  jump_interval_duration=None, **kwargs):
         # set the parameters, initialize the covariance matrix
-        super(SSAdaptiveNormal, self).__init__(
+        super().__init__(
             parameters, cov=cov, jump_interval=jump_interval,
             jump_interval_duration=jump_interval_duration)
         # set up the adaptation parameters
@@ -549,7 +542,6 @@ class SSAdaptiveNormal(SSAdaptiveSupport, Normal):
 #
 
 
-@add_metaclass(ABCMeta)
 class ATAdaptiveSupport(BaseAdaptiveSupport):
     r"""Utility class for adding ATAdaptiveNormal proposal support.
 
@@ -760,7 +752,7 @@ class ATAdaptiveNormal(ATAdaptiveSupport, Normal):
                  componentwise=False, start_step=1, target_rate=None,
                  jump_interval=1):
         # set the parameters, initialize the covariance matrix
-        super(ATAdaptiveNormal, self).__init__(
+        super().__init__(
             parameters, jump_interval=jump_interval,
             jump_interval_duration=adaptation_duration)
         # set up the adaptation parameters
